# How to install

The package can be installed simply by

```shell
pip install seaduck
```

or, alternatively (not available yet)

```shell
conda install -c conda-forge seaduck
```

or, alternatively (for latest code development), see [a guide for new contibutors](guide_for_developer.md).

## Required dependencies

- python
- numpy
- xarray

## Optional dependencies

- pandas
- numba
- matplotlib
- dask
